@@ -1,10 +1,11 @@
 import logging
 import sssimp
-from sssimp import config
+from sssimp import config, jinja
 from sssimp.utils import mkdir, path_strip
 
 
-OUT_FILE = sssimp.OUTPUT_DIR / 'bundle.css'
+BUNDLE_FILE = 'bundle.css'
+OUT_FILE = sssimp.OUTPUT_DIR / BUNDLE_FILE
 CSS_DIR = sssimp.INPUT_DIR / 'css'
 
 def main():
@@ -24,4 +25,5 @@ def main():
                 out.write(css_file.read())
             print(file=out)
             time = max(time, file.stat().st_mtime)
-    sssimp.jinja.globals['BUNDLE_TIME'] = time
+    jinja.globals['BUNDLE_TIME'] = time
+    jinja.globals['BUNDLE_FILE'] = BUNDLE_FILE
